@@ -117,8 +117,15 @@ glmboost_fit <- function(object, family = GaussReg(), control = boost_control(),
     RET$predict <- function(newdata = NULL, mstop = mstop, ...) {
 
         if (!is.null(newdata)) {
-            mf <- object$menv@get("input", data = newdata)
-            x <- model.matrix(attr(mf, "terms"), data = mf)
+            if (is.null(object$menv)) {
+                if (!is.matrix(newdata) || any(dim(newdata) != dim(x)))
+                    stop(sQuote("newdata"), " is not a matrix with dimensions ",
+                         dim(x))
+                x <- newdata
+            } else {
+                mf <- object$menv@get("input", data = newdata)
+                x <- model.matrix(attr(mf, "terms"), data = mf)
+            }
         }
 
         tmp <- RET
@@ -198,7 +205,7 @@ hatvalues.glmboost <- function(model, ...) {
 print.glmboost <- function(x, ...) {
 
     cat("\n")
-    cat("\t Generalized Linear Models Fitted via Gradient Boosting) \n")
+    cat("\t Generalized Linear Models Fitted via Gradient Boosting\n")
     cat("\n")
     if (!is.null(x$call))
     cat("Call:\n", deparse(x$call), "\n\n", sep = "")
